@@ -344,7 +344,7 @@ class Answer(WikiRateEntity):
 
     def __init__(self, data):
         self.raw = data
-        if data["type"]["id"] != 43678:
+        if data.get("type") != "Answer" and data.get("type", {}).get("id") != 43678:
             raise WikiRate4PyException('Invalid type of entity')
 
         self.id = data.get("id")
@@ -357,8 +357,8 @@ class Answer(WikiRateEntity):
         if not data.get("sources").__str__().__contains__("Error rendering:"):
             for s in data.get("sources", []):
                 self.sources.append(SourceItem(s))
-        self.checked_by = data.get("checked_by").get("content")
-        self.check_requested = data.get("checked_by").get("check_requested")
+        self.checked_by = data.get("checked_by", [])
+        # self.check_requested = data.get("checked_by", {}).get("check_requested")
         self.url = data.get("html_url")
 
 
